/** Description of a foreign key constraint from point of view of a single attribute */
class SchemeDefReference {
    constructor(
        group,      // Integer beeing id of reference group (all SchemeDefReference instances forming a single reference)
        table,      // Name of table referenced
        attribute   // Name of referenced attribute within referenced table
    ) {
        this.group = group;
        this.table = table;
        this.attribute = attribute;
    }

    /**
    * Check if reference is semanticaly correct
    * @return mixed         Not falsey string describing first error or `false` (meaning no error)
    */
    validate(
        defs,       // SchemeDefs instance containing this object
        attribute,  // Foreign key attribute given by SchemeDefAttribute instance
        tablename   // Name of table `attribute` is part of
    ) {
        const target = defs.getAttributeByName(this.table, this.attribute);
        if (!(target instanceof SchemeDefAttribute))
            return '„' + tablename + '.' + attribute.name + '“ kann sich nicht auf das nicht existierende Attribut „' + this.table + '.'  + this.attribute + '“ beziehen.';
        if (target.datatype !== attribute.datatype)
            return 'Das Fremdschlüsselattribut „' + tablename + '.' + attribute.name + '“ müsste denselben Datentyp haben wie das zugehörige Attribut „' + this.table + '.'  + this.attribute + '“.';
        return false;
    }
}

/** Integer beeing id of reference group (all SchemeDefReference instances forming a single reference) */
SchemeDefReference.prototype.group = -1;

/** Name of table referenced */
SchemeDefReference.prototype.table = '';

/** Name of referenced attribute within referenced table */
SchemeDefReference.prototype.attribute = '';
